@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (C) 2003 Ross Burton <ross@burtonini.com>
  *
  * Sound Juicer - sj-main.c
@@ -32,11 +32,8 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <gconf/gconf-client.h>
-#include <nautilus-burn.h>
-#include <libgnome/gnome-help.h>
-#include <libgnome/gnome-url.h>
-#include <libgnomeui/gnome-ui-init.h>
-#include <libgnomeui/gnome-authentication-manager.h>
+#include <brasero-medium-selection.h>
+#include <brasero-volume.h>
 #include <profiles/gnome-media-profiles.h>
 #include <gst/gst.h>
 
@@ -89,7 +86,7 @@ GtkWidget *current_message_area;
 
 const char *path_pattern, *file_pattern;
 GFile *base_uri;
-NautilusBurnDrive *drive = NULL;
+BraseroDrive *drive = NULL;
 gboolean strip_chars;
 gboolean eject_finished;
 gboolean open_finished;
@@ -218,7 +215,7 @@ void on_eject_activate (GtkMenuItem *item, gpointer user_data)
   /* first make sure we're not playing */
   stop_playback ();
 
-  nautilus_burn_drive_eject (drive);
+  brasero_drive_eject (drive, FALSE, NULL);
 }
 
 gboolean on_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
@@ -235,10 +232,10 @@ gboolean on_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data
     gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Continue"), GTK_RESPONSE_REJECT);
     response = gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
-    
+
     if (response == GTK_RESPONSE_ACCEPT) {
       return FALSE;
-    } 
+    }
     return TRUE;
   }
   return FALSE;
@@ -391,12 +388,12 @@ set_message_area (GtkWidget *container,
 {
   if (current_message_area == message_area)
     return;
-  
+
   if (current_message_area != NULL)
     gtk_widget_destroy (current_message_area);
-  
+
   current_message_area = message_area;
-  
+
   if (message_area == NULL)
     return;
 
@@ -418,7 +415,7 @@ musicbrainz_submit_message_area_new (char *title, char *artist)
   message_area = gedit_message_area_new ();
 
   button = gedit_message_area_add_button (GEDIT_MESSAGE_AREA (message_area),
-                                          _("_Submit Album"),
+                                          _("S_ubmit Album"),
                                           GTK_RESPONSE_OK);
   gedit_message_area_add_button (GEDIT_MESSAGE_AREA (message_area),
                                  GTK_STOCK_CANCEL,
@@ -426,15 +423,15 @@ musicbrainz_submit_message_area_new (char *title, char *artist)
 
   /* Translators: title, artist */
   primary_text = g_strdup_printf (_("Could not find %s by %s on MusicBrainz."), title, artist);
-  
+
   set_message_area_text_and_icon (GEDIT_MESSAGE_AREA (message_area),
                                   "gtk-dialog-info",
                                   primary_text,
                                   _("You can improve the MusicBrainz database by adding this album."),
                                   button);
-  
+
   g_free (primary_text);
-  
+
   return message_area;
 }
 
@@ -446,7 +443,7 @@ musicbrainz_submit_message_area_response (GeditMessageArea *message_area,
   if (response_id == GTK_RESPONSE_OK) {
     on_submit_activate (NULL, NULL);
   }
-  
+
   set_message_area (message_area_eventbox, NULL);
 }
 
@@ -523,7 +520,7 @@ static void update_ui_for_album (AlbumDetails *album)
     gtk_widget_set_sensitive (prev_menuitem, FALSE);
     gtk_widget_set_sensitive (next_menuitem, FALSE);
     set_duplication (TRUE);
-    
+
     for (l = album->tracks; l; l=g_list_next (l)) {
       GtkTreeIter iter;
       TrackDetails *track = (TrackDetails*)l->data;
@@ -538,7 +535,7 @@ static void update_ui_for_album (AlbumDetails *album)
                           COLUMN_DURATION, track->duration,
                           COLUMN_DETAILS, track,
                           -1);
-     total_no_of_tracks++; 
+     total_no_of_tracks++;
     }
     no_of_tracks_selected=total_no_of_tracks;
 
@@ -563,10 +560,10 @@ static void update_ui_for_album (AlbumDetails *album)
                         "response",
                         G_CALLBACK (musicbrainz_submit_message_area_response),
                         NULL);
-      
+
       gedit_message_area_set_default_response (GEDIT_MESSAGE_AREA (message_area),
                                                GTK_RESPONSE_CANCEL);
-      
+
       gtk_widget_show (message_area);
     }
   }
@@ -588,7 +585,7 @@ static void album_row_activated (GtkTreeView *treeview,
  * Callback that gets fired when an the selection changes. We use this to
  * change the sensitivity of the continue button
  */
-static void selected_album_changed (GtkTreeSelection *selection, 
+static void selected_album_changed (GtkTreeSelection *selection,
                                     gpointer *user_data)
 {
   GtkWidget *ok_button = GTK_WIDGET (user_data);
@@ -786,7 +783,7 @@ static void open_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *ent
 static void audio_volume_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
   g_assert (strcmp (entry->key, GCONF_AUDIO_VOLUME) == 0);
-  
+
   GtkWidget *volb = glade_xml_get_widget (glade, "volume_button");
   if (entry->value == NULL) {
     gtk_scale_button_set_value (GTK_SCALE_BUTTON (volb), 1.0);
@@ -804,10 +801,10 @@ metadata_cb (SjMetadataGetter *m, GList *albums, GError *error)
     gdk_window_set_cursor (main_window->window, NULL);
     /* Clear the statusbar message */
     gtk_statusbar_pop(GTK_STATUSBAR(status_bar), 0);
-  
+
   if (error && !(error->code == SJ_ERROR_CD_NO_MEDIA)) {
     GtkWidget *dialog;
-    
+
     dialog = gtk_message_dialog_new (realized ? GTK_WINDOW (main_window) : NULL, 0,
                                      GTK_MESSAGE_ERROR,
                                      GTK_BUTTONS_CLOSE,
@@ -851,7 +848,7 @@ metadata_cb (SjMetadataGetter *m, GList *albums, GError *error)
     albums = NULL;
   }
   update_ui_for_album (current_album);
-  
+
   if (autostart) {
     g_signal_emit_by_name (extract_button, "activate", NULL);
     autostart = FALSE;
@@ -863,19 +860,21 @@ metadata_cb (SjMetadataGetter *m, GList *albums, GError *error)
 }
 
 static gboolean
-is_audio_cd (NautilusBurnDrive *drive)
+is_audio_cd (BraseroDrive *drive)
 {
-  NautilusBurnMediaType type;
-  gboolean audio;
-  if (drive == NULL) return FALSE;
-  type = nautilus_burn_drive_get_media_type_full (drive, NULL, NULL, NULL, &audio);
-  if (type == NAUTILUS_BURN_MEDIA_TYPE_ERROR) {
+  BraseroMedium *medium;
+  BraseroMedia type;
+
+  medium = brasero_drive_get_medium (drive);
+  if (medium == NULL) return FALSE;
+  type = brasero_medium_get_status (medium);
+  if (type == BRASERO_MEDIUM_UNSUPPORTED) {
     g_warning ("Error getting media type\n");
   }
-  if (type == NAUTILUS_BURN_MEDIA_TYPE_BUSY) {
+  if (type == BRASERO_MEDIUM_BUSY) {
     g_warning ("BUSY getting media type, should re-check\n");
   }
-  return audio;
+  return BRASERO_MEDIUM_IS (type, BRASERO_MEDIUM_HAS_AUDIO|BRASERO_MEDIUM_CD);
 }
 
 /**
@@ -887,10 +886,10 @@ static void reread_cd (gboolean ignore_no_media)
   GError *error = NULL;
   GdkCursor *cursor;
   gboolean realized = GTK_WIDGET_REALIZED (main_window);
-  
+
   /* Make sure nothing is playing */
   stop_playback ();
-  
+
   /* Set watch cursor */
   if (realized) {
     cursor = gdk_cursor_new_for_display (gdk_drawable_get_display (main_window->window), GDK_WATCH);
@@ -898,7 +897,7 @@ static void reread_cd (gboolean ignore_no_media)
     gdk_cursor_unref (cursor);
     gdk_display_sync (gdk_drawable_get_display (main_window->window));
   }
-  
+
   /* Set statusbar message */
   gtk_statusbar_push(GTK_STATUSBAR(status_bar), 0, _("Retrieving track listing...please wait."));
 
@@ -945,19 +944,21 @@ static void reread_cd (gboolean ignore_no_media)
 }
 
 static void
-media_added_cb (NautilusBurnDrive *drive,
-                gpointer           data)
+media_added_cb (BraseroMediumMonitor	*drive,
+		BraseroMedium		*medium,
+                gpointer           	 data)
 {
   if (extracting == TRUE) {
     /* FIXME: recover? */
   }
 
-  sj_debug (DEBUG_CD, "Media added to device %s\n", nautilus_burn_drive_get_device (drive));
+  sj_debug (DEBUG_CD, "Media added to device %s\n", brasero_drive_get_device (brasero_medium_get_drive (medium)));
   reread_cd (TRUE);
 }
 
 static void
-media_removed_cb (NautilusBurnDrive *drive,
+media_removed_cb (BraseroMediumMonitor	*drive,
+		  BraseroMedium		*medium,
                   gpointer           data)
 {
   if (extracting == TRUE) {
@@ -967,7 +968,7 @@ media_removed_cb (NautilusBurnDrive *drive,
   /* first make sure we're not playing */
   stop_playback ();
 
-  sj_debug (DEBUG_CD, "Media removed from device %s\n", nautilus_burn_drive_get_device (drive));
+  sj_debug (DEBUG_CD, "Media removed from device %s\n", brasero_drive_get_device (brasero_medium_get_drive (medium)));
   stop_ui_hack ();
   update_ui_for_album (NULL);
 }
@@ -975,18 +976,18 @@ media_removed_cb (NautilusBurnDrive *drive,
 static void
 set_drive_from_device (const char *device)
 {
-  NautilusBurnDriveMonitor *monitor;
+  BraseroMediumMonitor *monitor;
 
   if (drive) {
-    nautilus_burn_drive_unref (drive);
+    g_object_unref (drive);
     drive = NULL;
   }
 
   if (! device)
     return;
 
-  monitor = nautilus_burn_get_drive_monitor ();
-  drive = nautilus_burn_drive_monitor_get_drive_for_device (monitor, device);
+  monitor = brasero_medium_monitor_get_default ();
+  drive = brasero_medium_monitor_get_drive (monitor, device);
   if (! drive) {
     GtkWidget *dialog;
     char *message;
@@ -1005,8 +1006,8 @@ set_drive_from_device (const char *device)
     return;
   }
 
-  g_signal_connect (drive, "media-added", G_CALLBACK (media_added_cb), NULL);
-  g_signal_connect (drive, "media-removed", G_CALLBACK (media_removed_cb), NULL);
+  g_signal_connect (monitor, "medium-added", G_CALLBACK (media_added_cb), NULL);
+  g_signal_connect (monitor, "medium-removed", G_CALLBACK (media_removed_cb), NULL);
 }
 
 static void
@@ -1020,10 +1021,10 @@ set_device (const char* device, gboolean ignore_no_media)
     GtkWidget *dialog;
     char *message;
     const char *error;
-    
+
     error = g_strerror (errno);
     message = g_strdup_printf (_("Sound Juicer could not access the CD-ROM device '%s'"), device);
-    
+
     dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
                                      GTK_DIALOG_DESTROY_WITH_PARENT,
                                      GTK_MESSAGE_ERROR,
@@ -1047,32 +1048,31 @@ set_device (const char* device, gboolean ignore_no_media)
 
   sj_metadata_getter_set_cdrom (metadata, device);
   sj_extractor_set_device (extractor, device);
-  
+
   if (drive != NULL) {
-    tray_opened = nautilus_burn_drive_door_is_open (drive);
+    tray_opened = brasero_drive_is_door_open (drive);
     if (tray_opened == FALSE) {
       reread_cd (ignore_no_media);
     }
-#if HAVE_NAUTILUS_BURN_DRIVE_CAN_EJECT
-    // Enable/disable the eject options based on wether the drive supports ejection
-    gtk_widget_set_sensitive (eject, nautilus_burn_drive_can_eject (drive));
-#endif
+
+    /* Enable/disable the eject options based on wether the drive supports ejection */
+    gtk_widget_set_sensitive (eject, brasero_drive_can_eject (drive));
   }
 }
 
 gboolean cd_drive_exists (const char *device)
 {
-  NautilusBurnDriveMonitor *monitor;
-  NautilusBurnDrive *drive;
+  BraseroMediumMonitor *monitor;
+  BraseroDrive *drive;
   gboolean exists;
 
   if (device == NULL)
     return FALSE;
 
-  monitor = nautilus_burn_get_drive_monitor ();
-  drive = nautilus_burn_drive_monitor_get_drive_for_device (monitor, device);
+  monitor = brasero_medium_monitor_get_default ();
+  drive = brasero_medium_monitor_get_drive (monitor, device);
   exists = (drive != NULL);
-  nautilus_burn_drive_unref (drive);
+  g_object_unref (drive);
 
   return exists;
 }
@@ -1083,20 +1083,21 @@ prefs_get_default_device (void)
   static const char * default_device = NULL;
 
   if (default_device == NULL) {
-    NautilusBurnDriveMonitor *monitor;
-    NautilusBurnDrive *drive;
-    GList *drives;
+    BraseroMediumMonitor *monitor;
 
-    monitor = nautilus_burn_get_drive_monitor ();
-    drives = nautilus_burn_drive_monitor_get_drives (monitor);
+    BraseroDrive *drive;
+    GSList *drives;
+
+    monitor = brasero_medium_monitor_get_default ();
+    drives = brasero_medium_monitor_get_drives (monitor, BRASERO_DRIVE_TYPE_ALL);
     if (drives == NULL)
       return NULL;
 
     drive = drives->data;
-    default_device = nautilus_burn_drive_get_device (drive);
+    default_device = brasero_drive_get_device (drive);
 
-    g_list_foreach (drives, (GFunc)nautilus_burn_drive_unref, NULL);
-    g_list_free (drives);
+    g_slist_foreach (drives, (GFunc) g_object_unref, NULL);
+    g_slist_free (drives);
   }
   return default_device;
 }
@@ -1137,7 +1138,7 @@ static void device_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *e
 static void profile_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
 {
   GMAudioProfile *profile;
-  
+
   g_assert (strcmp (entry->key, GCONF_AUDIO_PROFILE) == 0);
   if (!entry->value) return;
   profile = gm_audio_profile_lookup (gconf_value_get_string (entry->value));
@@ -1147,7 +1148,7 @@ static void profile_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *
   if (profile == NULL || !sj_extractor_supports_profile(profile)) {
     GtkWidget *dialog;
     int response;
-    
+
     dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
                                      GTK_DIALOG_MODAL,
                                      GTK_MESSAGE_QUESTION,
@@ -1232,7 +1233,7 @@ void on_submit_activate (GtkWidget *menuitem, gpointer user_data)
   GError *error = NULL;
 
   if (current_submit_url) {
-    if (!gnome_url_show (current_submit_url, &error)) {
+      if (!gtk_show_uri (NULL, current_submit_url, GDK_CURRENT_TIME, &error)) {
       GtkWidget *dialog;
 
       dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
@@ -1290,7 +1291,7 @@ static void on_extract_toggled (GtkCellRendererToggle *cellrenderertoggle,
   /* extract is the old state here, so toggle */
   extract = !extract;
   gtk_list_store_set (track_store, &iter, COLUMN_EXTRACT, extract, -1);
-    
+
   /* Update the Extract buttons */
   if (extract) {
     /* If true, then we can extract */
@@ -1302,8 +1303,8 @@ static void on_extract_toggled (GtkCellRendererToggle *cellrenderertoggle,
     extract = FALSE;
     gtk_tree_model_foreach (GTK_TREE_MODEL (track_store), (GtkTreeModelForeachFunc)extract_available_foreach, &extract);
     gtk_widget_set_sensitive (extract_button, extract);
-    gtk_widget_set_sensitive (extract_menuitem, extract);   
-    no_of_tracks_selected--; 
+    gtk_widget_set_sensitive (extract_menuitem, extract);
+    no_of_tracks_selected--;
   }
   /* Enable and disable the Select/Deselect All buttons */
   if (no_of_tracks_selected == total_no_of_tracks) {
@@ -1354,11 +1355,44 @@ static void on_cell_edited (GtkCellRendererText *renderer,
   }
   g_free (artist);
   g_free (title);
+
   return;
 }
- 
+
+/*
+ * Remove all of the data which is intrinsic to the album being correctly
+ * detected, such as MusicBrainz IDs, ASIN, and Wikipedia links.
+ */
+static void
+remove_musicbrainz_ids (AlbumDetails *album)
+{
+  GList *l;
+#define UNSET(id) g_free (album->id);           \
+  album->id = NULL;
+
+  UNSET (album_id);
+  UNSET (artist_id);
+  UNSET (asin);
+  UNSET (discogs);
+  UNSET (wikipedia);
+#undef UNSET
+
+#define UNSET(id) g_free (track->id);           \
+  track->id = NULL;
+
+  for (l = album->tracks; l; l = l->next) {
+    TrackDetails *track = l->data;
+    UNSET (track_id);
+    UNSET (artist_id);
+  }
+#undef UNSET
+}
+
 void on_title_edit_changed(GtkEditable *widget, gpointer user_data) {
   g_return_if_fail (current_album != NULL);
+
+  remove_musicbrainz_ids (current_album);
+
   if (current_album->title) {
     g_free (current_album->title);
   }
@@ -1371,7 +1405,9 @@ void on_artist_edit_changed(GtkEditable *widget, gpointer user_data) {
   gchar *current_track_artist, *former_album_artist = NULL;
 
   g_return_if_fail (current_album != NULL);
-  
+
+  remove_musicbrainz_ids (current_album);
+
   /* Unset the sortable artist field, as we can't change it automatically */
   if (current_album->artist_sortname) {
     g_free (current_album->artist_sortname);
@@ -1387,26 +1423,26 @@ void on_artist_edit_changed(GtkEditable *widget, gpointer user_data) {
     g_free (former_album_artist);
     return;
   }
-  
+
   /* Set the artist field in each tree row */
   do {
     gtk_tree_model_get (GTK_TREE_MODEL (track_store), &iter, COLUMN_ARTIST, &current_track_artist, -1);
     /* Change track artist if it matched album artist before the change */
     if ((strcasecmp (current_track_artist, former_album_artist) == 0) || (strcasecmp (current_track_artist, current_album->artist) == 0)) {
       gtk_tree_model_get (GTK_TREE_MODEL (track_store), &iter, COLUMN_DETAILS, &track, -1);
-      
+
       g_free (track->artist);
       track->artist = g_strdup (current_album->artist);
-      
+
       if (track->artist_sortname) {
         g_free (track->artist_sortname);
         track->artist_sortname = NULL;
       }
-      
+
       gtk_list_store_set (track_store, &iter, COLUMN_ARTIST, track->artist, -1);
     }
   } while (gtk_tree_model_iter_next (GTK_TREE_MODEL (track_store), &iter));
- 
+
   g_free (former_album_artist);
 }
 
@@ -1421,9 +1457,9 @@ void on_genre_edit_changed(GtkEditable *widget, gpointer user_data) {
 void on_year_edit_changed(GtkEditable *widget, gpointer user_data) {
   const gchar* yearstr;
   int year;
-  
+
   g_return_if_fail (current_album != NULL);
-  
+
   yearstr = gtk_entry_get_text (GTK_ENTRY (widget));
   year = atoi (yearstr);
   if (year > 0) {
@@ -1436,21 +1472,19 @@ void on_year_edit_changed(GtkEditable *widget, gpointer user_data) {
 }
 
 void on_disc_number_edit_changed(GtkEditable *widget, gpointer user_data) {
-    const gchar* discstr;  
+    const gchar* discstr;
     int disc_number;
 
     g_return_if_fail (current_album != NULL);
     discstr = gtk_entry_get_text (GTK_ENTRY (widget));
     disc_number = atoi(discstr);
-    if (disc_number > 0)
-        current_album->disc_number = disc_number;
+    current_album->disc_number = disc_number;
 }
 
 void on_contents_activate(GtkWidget *button, gpointer user_data) {
   GError *error = NULL;
 
-  /* If/when we drop libgnome, simply spawn the URI ghelp:sound-juicer. */
-  gnome_help_display ("sound-juicer", NULL, &error);
+  gtk_show_uri (NULL, "ghelp:sound-juicer", GDK_CURRENT_TIME, &error);
   if (error) {
     GtkWidget *dialog;
 
@@ -1508,33 +1542,42 @@ on_message_received (const char *message, gpointer user_data)
 static gboolean
 is_cd_duplication_available()
 {
-  // First check the nautilus-cd-burner tool is available in the path
-  gchar* nautilus_cd_burner = g_find_program_in_path ("nautilus-cd-burner");
-  if (nautilus_cd_burner == NULL) {
+  /* First check the brasero tool is available in the path */
+  gchar* brasero_cd_burner = g_find_program_in_path ("brasero");
+  if (brasero_cd_burner == NULL) {
     return FALSE;
-  } 
-  g_free(nautilus_cd_burner);
+  }
+  g_free(brasero_cd_burner);
 
-  // Second check the cdrdao tool is available in the path
+  /* Second check the cdrdao tool is available in the path */
   gchar* cdrdao = g_find_program_in_path ("cdrdao");
   if (cdrdao == NULL) {
     return FALSE;
-  } 
-  g_free(cdrdao);  
+  }
+  g_free(cdrdao);
 
-  // Now check that there is at least one cd recorder available
-  GList                    *drives;
-  NautilusBurnDriveMonitor *monitor;
+  /* Now check that there is at least one cd recorder available */
+  BraseroMediumMonitor     *monitor;
+  GSList		   *drives;
+  GSList		   *iter;
 
-  monitor = nautilus_burn_get_drive_monitor ();
-  drives = nautilus_burn_drive_monitor_get_recorder_drives (monitor);
+  monitor = brasero_medium_monitor_get_default ();
+  drives = brasero_medium_monitor_get_drives (monitor, BRASERO_DRIVE_TYPE_ALL);
 
-  if (drives == NULL) {
-     return FALSE;
+  for (iter = drives; iter; iter = iter->next) {
+    BraseroDrive *drive;
+
+    drive = iter->data;
+    if (brasero_drive_can_write (drive)) {
+      g_slist_foreach (drives, (GFunc) g_object_unref, NULL);
+      g_slist_free (drives);
+      return TRUE;
+    }
   }
 
-  g_list_free (drives);
-  return TRUE;
+  g_slist_foreach (drives, (GFunc) g_object_unref, NULL);
+  g_slist_free (drives);
+  return FALSE;
 }
 
 /**
@@ -1545,8 +1588,8 @@ void on_duplicate_activate (GtkWidget *button, gpointer user_data)
   GError *error = NULL;
   const gchar* device;
 
-  device = nautilus_burn_drive_get_device (drive);
-  if (!g_spawn_command_line_async (g_strconcat ("nautilus-cd-burner --source-device=", device, NULL), &error)) {
+  device = brasero_drive_get_device (drive);
+  if (!g_spawn_command_line_async (g_strconcat ("brasero -c ", device, NULL), &error)) {
       GtkWidget *dialog;
 
       dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
@@ -1578,7 +1621,6 @@ static void set_duplication(gboolean enabled)
 
 int main (int argc, char **argv)
 {
-  GnomeProgram *program;
   GError *error = NULL;
   GtkTreeSelection *selection;
   char *device = NULL, **uris = NULL;
@@ -1597,31 +1639,29 @@ int main (int argc, char **argv)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  ctx = g_option_context_new (N_("- Extract music from your CDs"));
-  g_option_context_add_main_entries (ctx, entries, GETTEXT_PACKAGE);  
-  g_option_context_set_translation_domain(ctx, GETTEXT_PACKAGE);
-  g_option_context_add_group (ctx, gst_init_get_option_group ());
-  g_option_context_set_ignore_unknown_options (ctx, TRUE);
-
-  program = gnome_program_init ("sound-juicer",
-                      VERSION, LIBGNOMEUI_MODULE,
-                      argc, argv,
-                      GNOME_PROGRAM_STANDARD_PROPERTIES,
-                      GNOME_PARAM_GOPTION_CONTEXT, ctx,
-                      NULL);
-
   g_set_application_name (_("Sound Juicer"));
 
-  gnome_authentication_manager_init ();
+  ctx = g_option_context_new (N_("- Extract music from your CDs"));
+  g_option_context_add_main_entries (ctx, entries, GETTEXT_PACKAGE);
+  g_option_context_set_translation_domain(ctx, GETTEXT_PACKAGE);
+  g_option_context_add_group (ctx, gtk_get_option_group (TRUE));
+  g_option_context_add_group (ctx, gst_init_get_option_group ());
+  g_option_context_add_group (ctx, brasero_media_get_option_group ());
+  g_option_context_set_ignore_unknown_options (ctx, TRUE);
+
+  g_option_context_parse (ctx, &argc, &argv, &error);
+  if (error != NULL) {
+      g_printerr ("Error parsing options: %s", error->message);
+      exit (1);
+  }
+  g_option_context_free (ctx);
 
   sj_debug_init ();
 
   sj_stock_init ();
 
-  nautilus_burn_init ();
-
   gtk_window_set_default_icon_name ("sound-juicer");
-  
+
   connection = bacon_message_connection_new ("sound-juicer");
   if (bacon_message_connection_get_is_server (connection) == FALSE) {
     bacon_message_connection_send (connection, RAISE_WINDOW);
@@ -1631,6 +1671,8 @@ int main (int argc, char **argv)
     bacon_message_connection_set_callback (connection, on_message_received, NULL);
   }
 
+  brasero_media_library_start ();
+
   metadata = sj_metadata_getter_new ();
   g_signal_connect (metadata, "metadata", G_CALLBACK (metadata_cb), NULL);
 
@@ -1668,7 +1710,9 @@ int main (int argc, char **argv)
     glade = glade_xml_new (INSTALLED_GLADE, NULL, NULL);
   }
   if (glade == NULL) {
-    g_error_new (0, 0, _("The interface file for Sound Juicer could not be read."));
+    error = g_error_new (g_quark_from_static_string ("sound-juicer"),
+                         1, /* this is made up */
+                         _("The interface file for Sound Juicer could not be read."));
     error_on_start (error);
     g_error_free (error);
     exit (1);
@@ -1708,7 +1752,7 @@ int main (int argc, char **argv)
     g_signal_connect_swapped (play_button, "destroy",
                               G_CALLBACK (gtk_widget_destroy),
                               fake_button1);
-    
+
     fake_button2 = gtk_button_new_from_stock (GTK_STOCK_MEDIA_PAUSE);
     gtk_size_group_add_widget (size_group, fake_button2);
     g_signal_connect_swapped (play_button, "destroy",
@@ -1725,7 +1769,7 @@ int main (int argc, char **argv)
   {
     GtkTreeViewColumn *column;
     GtkCellRenderer *renderer;
-    
+
     toggle_renderer = gtk_cell_renderer_toggle_new ();
     g_signal_connect (toggle_renderer, "toggled", G_CALLBACK (on_extract_toggled), NULL);
     column = gtk_tree_view_column_new_with_attributes ("",
@@ -1769,7 +1813,7 @@ int main (int argc, char **argv)
     g_signal_connect (artist_renderer, "edited", G_CALLBACK (on_cell_edited), GUINT_TO_POINTER (COLUMN_ARTIST));
     g_object_set (G_OBJECT (artist_renderer), "editable", TRUE, NULL);
     gtk_tree_view_append_column (GTK_TREE_VIEW (track_listview), column);
-    
+
     renderer = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes (_("Duration"),
                                                        renderer,
@@ -1832,7 +1876,7 @@ int main (int argc, char **argv)
     return 0;
   }
 
-  // Set whether duplication of a cd is available using the nautilus-cd-burner tool
+  /* Set whether duplication of a cd is available using the brasero tool */
   gtk_widget_set_sensitive (duplicate, FALSE);
   duplication_enabled = is_cd_duplication_available();
 
@@ -1840,12 +1884,11 @@ int main (int argc, char **argv)
   gtk_widget_show (main_window);
   gtk_main ();
 
-  nautilus_burn_shutdown ();
-
   g_object_unref (base_uri);
   g_object_unref (metadata);
   g_object_unref (extractor);
   g_object_unref (gconf_client);
-  g_object_unref (program);
+  brasero_media_library_stop ();
+
   return 0;
 }
