@@ -28,12 +28,11 @@
 #endif /* HAVE_CONFIG_H */
 
 #include <glib/gi18n.h>
-#include <nautilus-burn-drive.h>
+#include <brasero-medium-selection.h>
 #include <gconf/gconf-client.h>
 #include <glade/glade-xml.h>
-#include <gtk/gtkwidget.h>
+#include <gio/gio.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkliststore.h>
 #include "sj-extractor.h"
 
 /**
@@ -97,12 +96,12 @@ extern GtkListStore *track_store;
 /**
  * The device we are extracting from.
  */
-extern NautilusBurnDrive *drive;
+extern BraseroDrive *drive;
 
 /**
  * The root path to write files too
  */
-extern char *base_uri;
+extern GFile *base_uri;
 
 /**
  * The pattern to expand when naming folders
